.. _overview:

Overview: About PyLadies Chapters
=================================

Types of Chapters
-----------------

A chapter can be:

#. a geographic chapter: for a city, region, state, or country
#. a student chapter: for a university, college, or school
#. an interest group chapter: for any topic (e.g. PyGame, SciPy, Django)

The larger the chapter, the harder it is to meet in person. Large chapters’ events will be mostly virtual meetups that occur online, whereas small chapters’ events tend to be in-person meetups.

A chapter can consist of sub-chapters, making both the in-person and virtual meetups possible.

Chapter Size
------------

It’s fine if your chapter is small. Having just 2-3 women who meet regularly to exchange Python tips and tricks counts as a chapter. What matters most is *quality*, not quantity.

Larger chapters have more flexibility to organize different types of events, but it’s harder to get everyone together for dinner.
